==> zio-aws-chimesdkmessaging_2.13-5.17.160.1-sources.jar: zio/aws/chimesdkmessaging/model/CreateChannelMembershipRequest.scala <==
package zio.aws.chimesdkmessaging.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.chimesdkmessaging.model.primitives.ChimeArn
import scala.jdk.CollectionConverters._
final case class CreateChannelMembershipRequest(
    channelArn: ChimeArn,
    memberArn: ChimeArn,
    `type`: zio.aws.chimesdkmessaging.model.ChannelMembershipType,
    chimeBearer: ChimeArn
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmessaging.model.CreateChannelMembershipRequest = {
    import CreateChannelMembershipRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmessaging.model.CreateChannelMembershipRequest
      .builder()
      .channelArn(ChimeArn.unwrap(channelArn): java.lang.String)
      .memberArn(ChimeArn.unwrap(memberArn): java.lang.String)
      .`type`(`type`.unwrap)
      .chimeBearer(ChimeArn.unwrap(chimeBearer): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.chimesdkmessaging.model.CreateChannelMembershipRequest.ReadOnly =
    zio.aws.chimesdkmessaging.model.CreateChannelMembershipRequest
      .wrap(buildAwsValue())
}
object CreateChannelMembershipRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmessaging.model.CreateChannelMembershipRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.chimesdkmessaging.model.CreateChannelMembershipRequest =
      zio.aws.chimesdkmessaging.model.CreateChannelMembershipRequest(
        channelArn,
        memberArn,
        `type`,
        chimeBearer
      )
    def channelArn: ChimeArn
    def memberArn: ChimeArn
    def `type`: zio.aws.chimesdkmessaging.model.ChannelMembershipType
    def chimeBearer: ChimeArn
    def getChannelArn: ZIO[Any, Nothing, ChimeArn] = ZIO.succeed(channelArn)
    def getMemberArn: ZIO[Any, Nothing, ChimeArn] = ZIO.succeed(memberArn)
    def getType: ZIO[
      Any,
      Nothing,
      zio.aws.chimesdkmessaging.model.ChannelMembershipType
    ] = ZIO.succeed(`type`)
    def getChimeBearer: ZIO[Any, Nothing, ChimeArn] = ZIO.succeed(chimeBearer)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.CreateChannelMembershipRequest
  ) extends zio.aws.chimesdkmessaging.model.CreateChannelMembershipRequest.ReadOnly {
    override val channelArn: ChimeArn =
      zio.aws.chimesdkmessaging.model.primitives.ChimeArn(impl.channelArn())
    override val memberArn: ChimeArn =
      zio.aws.chimesdkmessaging.model.primitives.ChimeArn(impl.memberArn())
    override val `type`: zio.aws.chimesdkmessaging.model.ChannelMembershipType =
      zio.aws.chimesdkmessaging.model.ChannelMembershipType.wrap(impl.`type`())
    override val chimeBearer: ChimeArn =
      zio.aws.chimesdkmessaging.model.primitives.ChimeArn(impl.chimeBearer())
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.CreateChannelMembershipRequest
  ): zio.aws.chimesdkmessaging.model.CreateChannelMembershipRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-chimesdkmessaging_2.13-6.20.103.1-sources.jar: zio/aws/chimesdkmessaging/model/CreateChannelMembershipRequest.scala <==
package zio.aws.chimesdkmessaging.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.chimesdkmessaging.model.primitives.{SubChannelId, ChimeArn}
import scala.jdk.CollectionConverters._
final case class CreateChannelMembershipRequest(
    channelArn: ChimeArn,
    memberArn: ChimeArn,
    `type`: zio.aws.chimesdkmessaging.model.ChannelMembershipType,
    chimeBearer: ChimeArn,
    subChannelId: Optional[SubChannelId] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmessaging.model.CreateChannelMembershipRequest = {
    import CreateChannelMembershipRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmessaging.model.CreateChannelMembershipRequest
      .builder()
      .channelArn(ChimeArn.unwrap(channelArn): java.lang.String)
      .memberArn(ChimeArn.unwrap(memberArn): java.lang.String)
      .`type`(`type`.unwrap)
      .chimeBearer(ChimeArn.unwrap(chimeBearer): java.lang.String)
      .optionallyWith(
        subChannelId.map(value => SubChannelId.unwrap(value): java.lang.String)
      )(_.subChannelId)
      .build()
  }
  def asReadOnly
      : zio.aws.chimesdkmessaging.model.CreateChannelMembershipRequest.ReadOnly =
    zio.aws.chimesdkmessaging.model.CreateChannelMembershipRequest
      .wrap(buildAwsValue())
}
object CreateChannelMembershipRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmessaging.model.CreateChannelMembershipRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.chimesdkmessaging.model.CreateChannelMembershipRequest =
      zio.aws.chimesdkmessaging.model.CreateChannelMembershipRequest(
        channelArn,
        memberArn,
        `type`,
        chimeBearer,
        subChannelId.map(value => value)
      )
    def channelArn: ChimeArn
    def memberArn: ChimeArn
    def `type`: zio.aws.chimesdkmessaging.model.ChannelMembershipType
    def chimeBearer: ChimeArn
    def subChannelId: Optional[SubChannelId]
    def getChannelArn: ZIO[Any, Nothing, ChimeArn] = ZIO.succeed(channelArn)
    def getMemberArn: ZIO[Any, Nothing, ChimeArn] = ZIO.succeed(memberArn)
    def getType: ZIO[
      Any,
      Nothing,
      zio.aws.chimesdkmessaging.model.ChannelMembershipType
    ] = ZIO.succeed(`type`)
    def getChimeBearer: ZIO[Any, Nothing, ChimeArn] = ZIO.succeed(chimeBearer)
    def getSubChannelId: ZIO[Any, AwsError, SubChannelId] =
      AwsError.unwrapOptionField("subChannelId", subChannelId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.CreateChannelMembershipRequest
  ) extends zio.aws.chimesdkmessaging.model.CreateChannelMembershipRequest.ReadOnly {
    override val channelArn: ChimeArn =
      zio.aws.chimesdkmessaging.model.primitives.ChimeArn(impl.channelArn())
    override val memberArn: ChimeArn =
      zio.aws.chimesdkmessaging.model.primitives.ChimeArn(impl.memberArn())
    override val `type`: zio.aws.chimesdkmessaging.model.ChannelMembershipType =
      zio.aws.chimesdkmessaging.model.ChannelMembershipType.wrap(impl.`type`())
    override val chimeBearer: ChimeArn =
      zio.aws.chimesdkmessaging.model.primitives.ChimeArn(impl.chimeBearer())
    override val subChannelId: Optional[SubChannelId] = zio.aws.core.internal
      .optionalFromNullable(impl.subChannelId())
      .map(value =>
        zio.aws.chimesdkmessaging.model.primitives.SubChannelId(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.CreateChannelMembershipRequest
  ): zio.aws.chimesdkmessaging.model.CreateChannelMembershipRequest.ReadOnly =
    new Wrapper(impl)
}
